@@ -1,7 +1,7 @@
 """
 Type annotations for codestar-notifications service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codestar_notifications/type_defs/)
 
 Usage::
 
@@ -42,14 +42,17 @@ __all__ = (
     "DescribeNotificationRuleResultTypeDef",
     "EventTypeSummaryTypeDef",
     "ListEventTypesFilterTypeDef",
+    "ListEventTypesRequestListEventTypesPaginateTypeDef",
     "ListEventTypesRequestRequestTypeDef",
     "ListEventTypesResultTypeDef",
     "ListNotificationRulesFilterTypeDef",
+    "ListNotificationRulesRequestListNotificationRulesPaginateTypeDef",
     "ListNotificationRulesRequestRequestTypeDef",
     "ListNotificationRulesResultTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResultTypeDef",
     "ListTargetsFilterTypeDef",
+    "ListTargetsRequestListTargetsPaginateTypeDef",
     "ListTargetsRequestRequestTypeDef",
     "ListTargetsResultTypeDef",
     "NotificationRuleSummaryTypeDef",
@@ -67,19 +70,33 @@ __all__ = (
     "UpdateNotificationRuleRequestRequestTypeDef",
 )
 
-CreateNotificationRuleRequestRequestTypeDef = TypedDict(
-    "CreateNotificationRuleRequestRequestTypeDef",
+_RequiredCreateNotificationRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateNotificationRuleRequestRequestTypeDef",
     {
         "Name": str,
         "EventTypeIds": Sequence[str],
         "Resource": str,
         "Targets": Sequence["TargetTypeDef"],
         "DetailType": DetailTypeType,
-        "ClientRequestToken": NotRequired[str],
-        "Tags": NotRequired[Mapping[str, str]],
-        "Status": NotRequired[NotificationRuleStatusType],
     },
 )
+_OptionalCreateNotificationRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateNotificationRuleRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+        "Tags": Mapping[str, str],
+        "Status": NotificationRuleStatusType,
+    },
+    total=False,
+)
+
+
+class CreateNotificationRuleRequestRequestTypeDef(
+    _RequiredCreateNotificationRuleRequestRequestTypeDef,
+    _OptionalCreateNotificationRuleRequestRequestTypeDef,
+):
+    pass
+
 
 CreateNotificationRuleResultTypeDef = TypedDict(
     "CreateNotificationRuleResultTypeDef",
@@ -104,13 +121,26 @@ DeleteNotificationRuleResultTypeDef = TypedDict(
     },
 )
 
-DeleteTargetRequestRequestTypeDef = TypedDict(
-    "DeleteTargetRequestRequestTypeDef",
+_RequiredDeleteTargetRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteTargetRequestRequestTypeDef",
     {
         "TargetAddress": str,
-        "ForceUnsubscribeAll": NotRequired[bool],
     },
 )
+_OptionalDeleteTargetRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteTargetRequestRequestTypeDef",
+    {
+        "ForceUnsubscribeAll": bool,
+    },
+    total=False,
+)
+
+
+class DeleteTargetRequestRequestTypeDef(
+    _RequiredDeleteTargetRequestRequestTypeDef, _OptionalDeleteTargetRequestRequestTypeDef
+):
+    pass
+
 
 DescribeNotificationRuleRequestRequestTypeDef = TypedDict(
     "DescribeNotificationRuleRequestRequestTypeDef",
@@ -140,11 +170,12 @@ DescribeNotificationRuleResultTypeDef = TypedDict(
 EventTypeSummaryTypeDef = TypedDict(
     "EventTypeSummaryTypeDef",
     {
-        "EventTypeId": NotRequired[str],
-        "ServiceName": NotRequired[str],
-        "EventTypeName": NotRequired[str],
-        "ResourceType": NotRequired[str],
+        "EventTypeId": str,
+        "ServiceName": str,
+        "EventTypeName": str,
+        "ResourceType": str,
     },
+    total=False,
 )
 
 ListEventTypesFilterTypeDef = TypedDict(
@@ -155,13 +186,23 @@ ListEventTypesFilterTypeDef = TypedDict(
     },
 )
 
+ListEventTypesRequestListEventTypesPaginateTypeDef = TypedDict(
+    "ListEventTypesRequestListEventTypesPaginateTypeDef",
+    {
+        "Filters": Sequence["ListEventTypesFilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListEventTypesRequestRequestTypeDef = TypedDict(
     "ListEventTypesRequestRequestTypeDef",
     {
-        "Filters": NotRequired[Sequence["ListEventTypesFilterTypeDef"]],
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
+        "Filters": Sequence["ListEventTypesFilterTypeDef"],
+        "NextToken": str,
+        "MaxResults": int,
     },
+    total=False,
 )
 
 ListEventTypesResultTypeDef = TypedDict(
@@ -181,13 +222,23 @@ ListNotificationRulesFilterTypeDef = TypedDict(
     },
 )
 
+ListNotificationRulesRequestListNotificationRulesPaginateTypeDef = TypedDict(
+    "ListNotificationRulesRequestListNotificationRulesPaginateTypeDef",
+    {
+        "Filters": Sequence["ListNotificationRulesFilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListNotificationRulesRequestRequestTypeDef = TypedDict(
     "ListNotificationRulesRequestRequestTypeDef",
     {
-        "Filters": NotRequired[Sequence["ListNotificationRulesFilterTypeDef"]],
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
+        "Filters": Sequence["ListNotificationRulesFilterTypeDef"],
+        "NextToken": str,
+        "MaxResults": int,
     },
+    total=False,
 )
 
 ListNotificationRulesResultTypeDef = TypedDict(
@@ -222,13 +273,23 @@ ListTargetsFilterTypeDef = TypedDict(
     },
 )
 
+ListTargetsRequestListTargetsPaginateTypeDef = TypedDict(
+    "ListTargetsRequestListTargetsPaginateTypeDef",
+    {
+        "Filters": Sequence["ListTargetsFilterTypeDef"],
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListTargetsRequestRequestTypeDef = TypedDict(
     "ListTargetsRequestRequestTypeDef",
     {
-        "Filters": NotRequired[Sequence["ListTargetsFilterTypeDef"]],
-        "NextToken": NotRequired[str],
-        "MaxResults": NotRequired[int],
+        "Filters": Sequence["ListTargetsFilterTypeDef"],
+        "NextToken": str,
+        "MaxResults": int,
     },
+    total=False,
 )
 
 ListTargetsResultTypeDef = TypedDict(
@@ -243,18 +304,20 @@ ListTargetsResultTypeDef = TypedDict(
 NotificationRuleSummaryTypeDef = TypedDict(
     "NotificationRuleSummaryTypeDef",
     {
-        "Id": NotRequired[str],
-        "Arn": NotRequired[str],
+        "Id": str,
+        "Arn": str,
     },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": NotRequired[int],
-        "PageSize": NotRequired[int],
-        "StartingToken": NotRequired[str],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
+    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -268,14 +331,27 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-SubscribeRequestRequestTypeDef = TypedDict(
-    "SubscribeRequestRequestTypeDef",
+_RequiredSubscribeRequestRequestTypeDef = TypedDict(
+    "_RequiredSubscribeRequestRequestTypeDef",
     {
         "Arn": str,
         "Target": "TargetTypeDef",
-        "ClientRequestToken": NotRequired[str],
     },
 )
+_OptionalSubscribeRequestRequestTypeDef = TypedDict(
+    "_OptionalSubscribeRequestRequestTypeDef",
+    {
+        "ClientRequestToken": str,
+    },
+    total=False,
+)
+
+
+class SubscribeRequestRequestTypeDef(
+    _RequiredSubscribeRequestRequestTypeDef, _OptionalSubscribeRequestRequestTypeDef
+):
+    pass
+
 
 SubscribeResultTypeDef = TypedDict(
     "SubscribeResultTypeDef",
@@ -304,18 +380,20 @@ TagResourceResultTypeDef = TypedDict(
 TargetSummaryTypeDef = TypedDict(
     "TargetSummaryTypeDef",
     {
-        "TargetAddress": NotRequired[str],
-        "TargetType": NotRequired[str],
-        "TargetStatus": NotRequired[TargetStatusType],
+        "TargetAddress": str,
+        "TargetType": str,
+        "TargetStatus": TargetStatusType,
     },
+    total=False,
 )
 
 TargetTypeDef = TypedDict(
     "TargetTypeDef",
     {
-        "TargetType": NotRequired[str],
-        "TargetAddress": NotRequired[str],
+        "TargetType": str,
+        "TargetAddress": str,
     },
+    total=False,
 )
 
 UnsubscribeRequestRequestTypeDef = TypedDict(
@@ -342,14 +420,27 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateNotificationRuleRequestRequestTypeDef = TypedDict(
-    "UpdateNotificationRuleRequestRequestTypeDef",
+_RequiredUpdateNotificationRuleRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateNotificationRuleRequestRequestTypeDef",
     {
         "Arn": str,
-        "Name": NotRequired[str],
-        "Status": NotRequired[NotificationRuleStatusType],
-        "EventTypeIds": NotRequired[Sequence[str]],
-        "Targets": NotRequired[Sequence["TargetTypeDef"]],
-        "DetailType": NotRequired[DetailTypeType],
     },
 )
+_OptionalUpdateNotificationRuleRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateNotificationRuleRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Status": NotificationRuleStatusType,
+        "EventTypeIds": Sequence[str],
+        "Targets": Sequence["TargetTypeDef"],
+        "DetailType": DetailTypeType,
+    },
+    total=False,
+)
+
+
+class UpdateNotificationRuleRequestRequestTypeDef(
+    _RequiredUpdateNotificationRuleRequestRequestTypeDef,
+    _OptionalUpdateNotificationRuleRequestRequestTypeDef,
+):
+    pass
